<?php if ( ! defined( 'ABSPATH' ) ) { die( 'Direct access forbidden.' ); }

/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * 
 * @package insidect
 */

if( ! function_exists('insidect_post_thumbnail') ) :
/**
 * Post Thumbnail
 */
	function insidect_post_thumbnail() {
		if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
			return;
		}

		$current_position = false;
		if (function_exists('fw_ext_sidebars_get_current_position')) {
			$current_position = fw_ext_sidebars_get_current_position();
		}

		if ( is_single() ) :
			?>

			<div class="post-thumbnail">
				<?php
				if ( ( in_array( $current_position,
						array( 'full', 'left' ) ) || is_page_template( 'page-templates/full-width.php' )
					|| empty($current_position)
				)
				) {
					the_post_thumbnail( 'full' );
				} else {
					the_post_thumbnail();
				}
				?>
			</div>
		
		<?php else : ?>

			<a class="post-thumbnail" href="<?php the_permalink(); ?>">
				<?php
				if ( !is_sticky() ) {
					if ( is_page_template( 'page-templates/blog-list.php' ) || is_page_template('page-templates/blog-large-list.php' ) || is_page_template( 'page-templates/blog-grid.php' ) || is_page_template( 'page-templates/blog-large-grid.php' ) || is_page_template( 'page-templates/blog-masonry.php' ) )  {
					the_post_thumbnail( 'medium' );
					}
					else {
						the_post_thumbnail( 'large' );	
					}
				} elseif ( ( in_array( $current_position,
						array( 'full', 'left' ) ) || is_page_template( 'page-templates/full-width.php' ) )
						|| empty($current_position)
				) {
					the_post_thumbnail( 'large' );
				} else {
					the_post_thumbnail();
				}
				?>
			</a>

		<?php endif; // End is_singular()
	}
endif;

if( ! function_exists('insidect_entry_title') ) {
/**
 * Post Entry Title
 */
	function insidect_entry_title() {
		if ( is_single() ) :
			the_title( '<h4 class="entry-title">', '</h4>' );
		elseif ( is_page_template('page-templates/blog-list.php') || is_page_template('page-templates/blog-grid.php') || is_page_template('page-templates/blog-large-list.php') || is_page_template('page-templates/blog-large-grid.php') || is_page_template('page-templates/blog-masonry.php') ) :
			the_title( '<h5 class="entry-title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">', '</a></h5>' );
		else :
			the_title( '<h4 class="entry-title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">', '</a></h4>' );
		endif;
	}
}

if ( ! function_exists( 'insidect_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and comments.
 */
function insidect_posted_on() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	$posted_on = sprintf(
		esc_html_x( '%s', 'post date', 'insidect' ),
		'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
	);

	echo '<span class="posted-on">' . $posted_on . '</span>'; // WPCS: XSS OK.

	if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link">';
			/* translators: %s: post title */
			comments_popup_link( sprintf( wp_kses( __( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'insidect' ), array( 'span' => array( 'class' => array() ) ) ), get_the_title() ) );
			echo '</span>';
	}
}
endif;

if ( ! function_exists( 'insidect_category_author' ) ) :
/**
 * Prints HTML with meta information for the categories, author
 */
function insidect_category_author() {
	// Hide category and tag text for pages.
	if ( 'post' === get_post_type() ) {
		$categories_list = get_the_category_list( esc_html__( ', ', 'insidect' ) );
		// if ( $categories_list && insidect_categorized_blog() ) {
			printf( '<span class="cat-links">' . esc_html__( '%1$s ', 'insidect' ) . '</span>', $categories_list ); // WPCS: XSS OK.
		// }
	}
	$avatar = sprintf(
		'<span class="vcard">' .get_avatar( get_the_author_meta('ID'), $size = '40' ). '</span>'
	);
	$byline = sprintf(
		esc_html_x( '%s', 'post author', 'insidect' ),
		'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
	);
	echo '<span class="cate-author">';
	if(is_single()) {
		echo wp_kses_post($avatar);
	}
	echo '<span class="byline">'.$byline.'</span>';
	echo '</span>';
}
endif;

if ( ! function_exists( 'insidect_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the tags.
 */
function insidect_entry_footer() {
	// Hide tag text for pages.
	if ( 'post' === get_post_type() ) {

		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', ' &sdot; ' );
		if ( $tags_list ) {
			printf( '<span class="tags-links"><i class="icon ion-ios-pricetag"></i>' . esc_html__( ' %1$s ', 'insidect' ) . '</span>', $tags_list ); // WPCS: XSS OK.
		}
	}
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function insidect_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'insidectcategories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'insidectcategories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so insidect_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so insidect_categorized_blog should return false.
		return false;
	}
}


/**
 * Header layout
 *
 */

if( ! function_exists('insidect_header_layout') ) {
	function insidect_header_layout() {
		/*PAGE OPTIONS*/
		$pid = get_queried_object_id();
		$p_header_layout = (function_exists('fw_get_db_post_option')) ? fw_get_db_post_option($pid, 'page_header_layout') : '';
		
		/*CUSTOMIZER*/
		$c_header_layout = get_theme_mod('header_layout_cfg', 'layout-2');

		if(isset($p_header_layout['gadget']) && $p_header_layout['gadget'] != 'default' ){
			switch($p_header_layout['gadget']) {
				case 'layout-1' :
					get_template_part('page-templates/header', 'layout-1');
					break;
				case 'layout-2' :
					get_template_part('page-templates/header', 'layout-2');
					break;
				case 'layout-3' :
					get_template_part('page-templates/header', 'layout-3');
				break;
				case 'layout-4' :
					get_template_part('page-templates/header', 'layout-4');
				break;
			}
		} else {
			switch($c_header_layout) {
				case 'layout-1' :
					get_template_part('page-templates/header', 'layout-1');
					break;
				case 'layout-2' :
					get_template_part('page-templates/header', 'layout-2');
					break;
				case 'layout-3' :
					get_template_part('page-templates/header', 'layout-3');
					break;
				case 'layout-4' :
					get_template_part('page-templates/header', 'layout-4');
					break;
				default :
					get_template_part('page-templates/header', 'layout-1');
					break;

			}
		}
	}
}

/*header layout edit*/
if(!function_exists('insidect_header_edit_location')){
	function insidect_header_edit_location($id = ''){
		$option = $id.'_edit_location';
		if(is_customize_preview()):
			echo '<div id="'. esc_attr($id) .'-edit-location" class="header-edit-location">';
				if ( class_exists( 'Kirki' ) ){
					echo Kirki::get_option($option);
				}
			echo '</div>';
		endif;
	}
}

/*breadcrumbs layout edit location*/
if(!function_exists('insidect_bread_edit_location')){
	function insidect_bread_edit_location($id = ''){
		$option = $id.'_edit_location';
		if(is_customize_preview()):
			echo '<div id="' . esc_attr($id) . '-edit-location">';
				if ( class_exists( 'Kirki' ) ){
					echo Kirki::get_option($option);
				}
			echo '</div>';
		endif;
	}
}

/*footer layout edit location*/
if(!function_exists('insidect_footer_edit_location')){
	function insidect_footer_edit_location($id = ''){
		$option = $id.'_edit_location';
		if(is_customize_preview()): ?>
			<div id="<?php echo esc_attr($id); ?>-edit-location">
				<?php
					if ( class_exists( 'Kirki' ) ){
						echo Kirki::get_option($option);
					}
				?>
			</div>
		<?php endif;
	}
}

/*logo*/
if(!function_exists('insidect_logo_image')){
	function insidect_logo_image(){
		$pid = get_queried_object_id();
		$p_lg = function_exists('fw_get_db_post_option') ? fw_get_db_post_option($pid, 'p_lg') : '';
		$p_header_layout = (function_exists('fw_get_db_post_option')) ? fw_get_db_post_option($pid, 'page_header_layout') : '';
		
		$c_lg = get_theme_mod('logo_img', '');
		$lg_img = '';

		$tag = 'div';
		if( is_front_page() ){
			$tag = 'h1';
		}
		
		if(isset($p_lg['gadget']) && $p_lg['gadget'] == 'custom'){
			$lg_img = $p_lg['custom']['lg_data']['url'];
		?>
			<<?php echo esc_attr($tag); ?> itemscope itemtype="http://schema.org/Organization" class="ht-logo">
				<?php 
					switch($p_header_layout['gadget']) {
						case 'layout-1' :
				 ?>
				<a class="lg" href="<?php echo esc_url(home_url('/')); ?>" itemprop="url">
	                <img
	                	class="img-logo"
	                	src="<?php echo esc_url($lg_img); ?>"
	                	alt="<?php esc_attr_e('Logo image', 'insidect'); ?>"
	                	itemprop="logo"
	                	width="350"
	                	height="45" >
	            </a>
	        	<?php 
	        			break;
	        			case 'layout-2' :
	        	?>
	        	<a class="lg" href="<?php echo esc_url(home_url('/')); ?>" itemprop="url">
	                <img
	                	class="img-logo"
	                	src="<?php echo esc_url($lg_img); ?>"
	                	alt="<?php esc_attr_e('Logo image', 'insidect'); ?>"
	                	itemprop="logo"
	                	width="90"
	                	height="20" >
	            </a>
	            <?php 
	        			break;
	        			case 'layout-3' :
	        	?>
	        	<a class="lg" href="<?php echo esc_url(home_url('/')); ?>" itemprop="url">
	                <img
	                	class="img-logo"
	                	src="<?php echo esc_url($lg_img); ?>"
	                	alt="<?php esc_attr_e('Logo image', 'insidect'); ?>"
	                	itemprop="logo"
	                	width="90"
	                	height="20" >
	            </a>
	            <?php 
	        			break;
	        			case 'layout-4' :
	        	?>
	        	<a class="lg" href="<?php echo esc_url(home_url('/')); ?>" itemprop="url">
	                <img
	                	class="img-logo"
	                	src="<?php echo esc_url($lg_img); ?>"
	                	alt="<?php esc_attr_e('Logo image', 'insidect'); ?>"
	                	itemprop="logo"
	                	width="90"
	                	height="20" >
	            </a>
	        <?php break; }?>
	            <span class="screen-reader-text"><?php echo esc_attr( bloginfo( 'name' ) ); ?></span>

            </<?php echo esc_attr($tag); ?>>
        <?php

			}else{
				$lg_img = ($c_lg != '') ? $c_lg : get_template_directory_uri().'/images/logo.png';
		?>
			<<?php echo esc_attr($tag); ?> itemscope itemtype="http://schema.org/Organization" class="ht-logo">
				<a class="lg" href="<?php echo esc_url(home_url("/")); ?>" itemprop="url">
	                <img
	                	class="img-logo"
	                	src="<?php echo esc_url($lg_img); ?>"
	                	alt="<?php esc_attr_e('Logo image', 'insidect'); ?>"
	                	itemprop="logo">
	            </a>
	            <span class="screen-reader-text"><?php echo esc_attr( bloginfo( 'name' ) ); ?></span>
			</<?php echo esc_attr($tag); ?>>
		<?php
		}
	}
}
/**
 * Display navigation to next/previous set of posts when applicable.
 */
if ( ! function_exists( 'insidect_paging_nav' ) ) : 
	function insidect_paging_nav( $wp_query = null ) {

		if ( ! $wp_query ) {
			$wp_query = $GLOBALS['wp_query'];
		}

		// Don't print empty markup if there's only one page.

		if ( $wp_query->max_num_pages < 2 ) {
			return;
		}
		

		$paged        = get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) : 1;
		$pagenum_link = html_entity_decode( get_pagenum_link() );
		$query_args   = array();
		$url_parts    = explode( '?', $pagenum_link );

		if ( isset( $url_parts[1] ) ) {
			wp_parse_str( $url_parts[1], $query_args );
		}

		$pagenum_link = remove_query_arg( array_keys( $query_args ), $pagenum_link );
		$pagenum_link = trailingslashit( $pagenum_link ) . '%_%';

		$format = $GLOBALS['wp_rewrite']->using_index_permalinks() && ! strpos( $pagenum_link,
			'index.php' ) ? 'index.php/' : '';
		$format .= $GLOBALS['wp_rewrite']->using_permalinks() ? user_trailingslashit( 'page/%#%',
			'paged' ) : '?paged=%#%';

		// Set up paginated links.
		$links = paginate_links( array(
			'base'      => $pagenum_link,
			'format'    => $format,
			'total'     => $wp_query->max_num_pages,
			'current'   => $paged,
			'mid_size'  => 1,
			'add_args'  => array_map( 'urlencode', $query_args ),
			'prev_text' => esc_html__( 'PREV', 'insidect' ),
			'next_text' => esc_html__( 'NEXT', 'insidect' ),
		) );

		if ( $links ) :
			// if ( !is_page_template('page-templates/blog-masonry.php') ) {
			?>
			<nav class="paging-navigation"   >
				<h2 class="screen-reader-text"><?php esc_html_e( 'Posts navigation', 'insidect'); ?></h2>
					<?php echo wp_kses($links,
					array(
						'ul' => array(
							'class' => array(),
						),
						'li' => array(),
						'span' => array(
							'class' => array(),
						),
						'a' => array(
							'class' => array(),
							'href' => array(),
						),
					)); ?>
			</nav>

		<?php
			// } else {
			// 	echo '<div class="load-more">LOAD MORE POST <i class="ion-load-a"></i></div>';
			// }
		endif;
	}
endif;

/**
 * Blog posts navigation
 */
if ( ! function_exists('insidect_theme_post_nav') ) :
	function insidect_theme_post_nav() {
		// Don't print empty markup if there's nowhere to navigate.
		$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
		$next     = get_adjacent_post( false, '', false );

		if ( ! $next && ! $previous ) {
			return;
		}
		if(!empty($previous)){
			$pre_link = get_permalink($previous);
			$pre_post_id = $previous->ID;
			$pre_post_thumb = wp_get_attachment_image_src( get_post_thumbnail_id($pre_post_id), 'insidect-blog-post-nav' );
		}
		if(!empty($next)){
			$next_link = get_permalink($next);
			$next_post_id = $next->ID;
			$next_post_thumb = wp_get_attachment_image_src( get_post_thumbnail_id($next_post_id), 'insidect-blog-post-nav' );
		}

		?>

		<div class="related-post flw">
			<?php
			if( is_attachment() ):
			?>
				<?php if(!empty($previous)){ ?>
					<div class="prev-post">
						<?php if($pre_post_thumb != false) : ?>
							<div class="control-post-img">
								<img src="<?php echo esc_url($pre_post_thumb[0]); ?>"
									 alt="<?php esc_attr_e('Post nav thumb', 'insidect'); ?>">
							</div>
						<?php endif; ?>
						<div class="control-post-desc">
							<a href="<?php echo esc_url($pre_link); ?>" class="control-post-btn">
								<i class="icon ion-arrow-left-c"></i>
								<?php esc_html_e('Previous', 'insidect'); ?>
							</a>
							<?php if(is_singular($post_types = 'fw-portfolio')) : ?>
								<h5 class="post-tit"><?php previous_post_link('%link'); ?></h5>
							<?php endif; ?>
						</div>
					</div>
				<?php } ?>
			<?php else : ?>
			<?php if(!empty($previous)){ ?>
				<div class="prev-post">
					<i class="icon ion-arrow-left-c"></i>
					<div class="control-post-desc">
						<a href="<?php echo esc_url($pre_link); ?>" class="control-post-btn">
							<?php esc_html_e('PREVIOUS POST', 'insidect'); ?>
						</a>
						<?php if(is_singular($post_types = 'fw-portfolio')) : ?>
								<h5 class="post-tit"><?php previous_post_link('%link'); ?></h5>
							<?php endif; ?>
					</div>
				</div>
			<?php } ?>
			<?php if(!empty($next)){ ?>
				<div class="next-post">
					<?php if($next_post_thumb != false) : ?>
						<div class="control-post-img">
							<img src="<?php echo esc_url($next_post_thumb[0]); ?>"
								 alt="<?php esc_attr_e('Post nav thumb', 'insidect'); ?>">
						</div>
					<?php else : ?>
							<i class="icon ion-arrow-right-c"></i>
					<?php endif; ?>
					<div class="control-post-desc">
						<a href="<?php echo esc_url($next_link); ?>" class="control-post-btn"><?php esc_html_e('NEXT POST', 'insidect'); ?></a>
						<?php if(is_singular($post_types = 'fw-portfolio')) : ?>
								<h5 class="post-tit"><?php next_post_link('%link');  ?></h5>
							<?php endif; ?>
					</div>
				</div>
			<?php } ?>
			<?php endif; ?>
		</div>
		<?php
	}
endif;

/**
 * Blog comments list
 */
if ( ! function_exists('insidect_comment_list') ) :
	function insidect_comment_list($comment, $args, $depth)	{
		$GLOBALS['comment'] = $comment;
		switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
		?>
			<li class="comment-post-pingback">
				<?php esc_html_e( 'Pingback:', 'insidect' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( esc_html__( 'Edit', 'insidect' ), '<span class="edit-link">', '</span>' ); ?>
			</li>
		<?php
		break;
		default :
		?>
			<li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">
			<div id="comment-<?php comment_ID(); ?>" class="comment-box">
				
				<div class="comment-author vcard">
					<?php echo get_avatar(get_the_author_meta('ID'), $size = '70'); ?>
				</div>

				<div class="comment-content-box">
					<div class="metadata">
						<?php printf( __('<cite class="fn">%s</cite>', 'insidect'), get_comment_author_link()) ?>
						<span class="separator">&sdot;</span>
						<p class="time"><a
						href="<?php echo htmlspecialchars(get_comment_link($comment->comment_ID)) ?>">
						<?php printf(esc_html__('%1$s', 'insidect'), insidect_get_comment_time()) ?></a></p>
					</div>
					
					<div class="comment-content">

						<div class="comment-content-inner">
							<?php if ($comment->comment_approved == '0') : ?>
								<em><?php esc_html_e('Your comment is awaiting moderation.', 'insidect') ?></em>
								<br/>
							<?php endif; ?>

							<div class="comment-text"><?php comment_text() ?></div>

							<div class="reply">
								<?php comment_reply_link(array_merge($args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
							</div>
						</div>
					<!-- /.comment-content-inner -->

					</div>
				</div>

			</div>
		<?php
		break;
		endswitch;
	}
endif;
/**
 *	Get comment time
 */
if ( ! function_exists('insidect_get_comment_time') ) :
	function insidect_get_comment_time( $comment_id = 0 ){
	    return sprintf( 
	        _x( '%s ago', 'Human-readable time', 'insidect' ), 
	        human_time_diff( 
	            get_comment_date( 'U', $comment_id ), 
	            current_time( 'timestamp' ) 
	        ) 
	    );
	}
endif;

/**
 * Footer display
 */
if(!function_exists('insidect_footer_display')) :
	function insidect_footer_display(){
		// page id
		$pid = get_queried_object_id();
		$footer_data = (function_exists('fw_get_db_post_option')) ? fw_get_db_post_option($pid, 'footer_data') : '';
		$c_footer_display = get_theme_mod('c_footer_display', '1');
		if(isset($footer_data) && $footer_data != 'default'){
			switch($footer_data){
				case 'enable' :
					insidect_footer_sidebar();
					break;
				case 'disable' :
					break;
				}
		}else{
			switch($c_footer_display){
				case '1' :
					insidect_footer_sidebar();
					break;
				case '0' :
					break;
				default :
					insidect_footer_sidebar();
					break;
			}
		}
	}
endif;

/**
 * Footer widget
 */
if(!function_exists('insidect_footer_sidebar')) :
	function insidect_footer_sidebar(){
		$pid = get_queried_object_id();
		$p_page_footer = (function_exists('fw_get_db_post_option')) ? fw_get_db_post_option($pid, 'p_page_footer') : '1';
		$gadget = $p_page_footer['gadget'];
		$final_footer_bg = '';

        if( isset($gadget) && $gadget == '1' ) {
			$p_footer_bg_select = $p_page_footer['1']['page_footer_bg'];
        	if( !empty($p_footer_bg_select) ) {
            	$final_footer_bg = 'style="background-color:' . $p_footer_bg_select . ';"';
        	}
		}
		if(is_active_sidebar('footer-widget')): ?>
			<div class="theme-footer-widget flw" <?php echo wp_kses_post($final_footer_bg); ?>>
				<div class="container">
					<div class="row">
						<?php dynamic_sidebar('footer-widget'); ?>
					</div>
				</div>
			</div>
		<?php endif;
	}
endif;

/* VISUAL COMPOSER *******************************************************************/
/*Extend VC*/
if ( class_exists( 'WPBakeryVisualComposerAbstract' ) ) {
	function insidect_require_VC() {
		require_once get_template_directory() . '/inc/vc-include.php';
	}
	add_action( 'init', 'insidect_require_VC', 2 );
}

if( ! function_exists('insidect_sc_excerpt') ) :
	function insidect_sc_excerpt(){
		$excerpt = get_the_content(get_the_ID());
		$excerpt = strip_tags($excerpt);
		$excerpt = substr($excerpt, 0, 120);
		$excerpt = $excerpt.'...';
		echo esc_html($excerpt);
	}
endif;