<?php if ( ! defined( 'ABSPATH' ) ) { die( 'Direct access forbidden.' ); }

if ( ! function_exists( 'insidect_action_theme_setup' ) ) : /**
 * Theme setup.
 *
 * Set up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support post thumbnails.
 * @internal
 */ {
	function insidect_action_theme_setup() {

		/*
		 * Make Theme available for translation.
		 */
		load_theme_textdomain( 'insidect', get_template_directory() . '/languages' );

		// Add RSS feed links to <head> for posts and comments.
		add_theme_support( 'automatic-feed-links' );
		// Enable support for Header Image.
		add_theme_support( 'custom-header' );
		// Enable support for Background images or solid colors.
		add_theme_support( 'custom-background' );
		// Enable support for Post Thumbnails, and declare two sizes.
		add_theme_support( 'post-thumbnails' );
		//set_post_thumbnail_size( 870, 432, true );
		add_image_size( 'insidect-blog-post-nav', 50, 50, true );
		add_image_size( 'insidect-rectangle-grid', 480, 685, true );
		add_image_size( 'insidect-blog-sc', 370, 190, true );
		add_image_size( 'insidect-widget-square', 450, 450, true );

		add_theme_support('title-tag');

        add_theme_support( 'custom-logo', array(
            'height'      => 55,
            'width'       => 205,
            'flex-width' => true,
        ) );

		/*
		 * Enable support for Post Formats.
		 * See http://codex.wordpress.org/Post_Formats
		 */
		add_theme_support( 'post-formats', array(
			'aside',
			'image',
			'video',
			'audio',
			'quote',
			'link',
			'gallery',
		) );
		
		// This theme uses its own gallery styles.
		add_filter( 'use_default_gallery_style', '__return_false' );
	}
}
endif;
add_action( 'after_setup_theme', 'insidect_action_theme_setup' );

/**
 * Register widget area
 */
function insidect_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Blog Sidebar', 'insidect' ),
		'id'            => 'sidebar-blog',
		'description'   => esc_html__( 'Blog Sidebar', 'insidect' ),
		'before_widget' => ' <div id="%1$s" class="row widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h6 class="widget-title">',
		'after_title'   => '</h6>',
    ) );
    register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget Area', 'insidect'),
		'id'            => 'footer-widget',
		'description'   => esc_html__( 'Appears in the footer section of the site.', 'insidect'),
		'before_widget' => '<div class="col-md-4 col-lg-4"><aside id="%1$s" class="widget-footer %2$s">',
		'after_widget'  => '</aside></div>',
		'before_title'  => '<h6 class="footer-widget-title">',
		'after_title'   => '</h6>',
	) );
}
add_action( 'widgets_init', 'insidect_widgets_init' );

/**
 * Install Demo content
 */
function insidect_backups_demos($demos) {
	$demos_array = array(
		'insidect' => array(
			'title' => esc_html__('Insidect Demo Full', 'insidect'),
			'screenshot' => get_template_directory_uri().'/screenshot.png',
			'preview_link' => 'http://haintheme.com/demo/wp/insidect',
		)
		// ...
	);

	$download_url = 'http://haintheme.com/ht-demos/';

	foreach ($demos_array as $id => $data) {
		$demo = new FW_Ext_Backups_Demo($id, 'piecemeal', array(
			'url' => $download_url,
			'file_id' => $id,
		));
		$demo->set_title($data['title']);
		$demo->set_screenshot($data['screenshot']);
		$demo->set_preview_link($data['preview_link']);

		$demos[ $demo->get_id() ] = $demo;

		unset($demo);
	}

	return $demos;
}

add_filter('fw:ext:backups-demo:demos', 'insidect_backups_demos');

/*
 * The Post Excerpt
 */
function insidect_excerpt() {
	if( is_page_template('page-templates/blog-list.php') || is_page_template('page-templates/blog-large-list.php') || is_page_template('page-templates/blog-masonry.php') ) {
		return sprintf( '...');
	} elseif ( is_page_template('page-templates/blog-grid.php') ||  is_page_template('page-templates/blog-large-grid.php') ) {
    	return '';
	} else {
		return sprintf( '<br><a class="more-link" href="%1$s">%2$s</a>',
	        get_permalink( get_the_ID() ),
	        esc_html__( 'READ MORE', 'insidect' )
	    );
	}
}
add_filter( 'excerpt_more', 'insidect_excerpt' );

function insidect_excerpt_length( $length ) {

	if ( is_page_template('page-templates/blog-list.php') || is_page_template('page-templates/blog-large-list.php') ) {
    	return 17;
    } elseif ( is_page_template('page-templates/blog-grid.php') || is_page_template('page-templates/blog-large-grid.php') ) {
    	return 0;
    } elseif ( is_page_template('page-templates/blog-masonry.php') ) {
    	return 30;
    } else {
    	return 50;
    }
}
add_filter( 'excerpt_length', 'insidect_excerpt_length', 999 );

/*
 * Blog Comment fields
 */
function insidect_comment_fields($fields) {
	$commenter = wp_get_current_commenter();
	$req = get_option( 'require_name_email' );
	$aria_req = ( $req ? " aria-required='true'" : '' );

    $fields =  array(
     
		'author' => '<p class="comment-form-author">
						<input class="text-fields" id="author" name="author" placeholder="'.esc_html__('YOUR NAME','insidect').'" type="text" size="30"'. $aria_req .'
					</p>',

		'email' => '<p class="comment-form-email">
						<input class="form-control" id="email" name="email" placeholder="'.esc_html__('YOUR EMAIL','insidect').'" type="text" size="30"' . $aria_req . '
					</p>',

		'url' => '<p class="comment-form-url">
						<input id="url" name="url" type="text" placeholder=" '.esc_html__('WEBSITE (OPTIONAL)','insidect').' " type="text" size="30"/></p>',
	);
    return $fields;
}
add_filter('comment_form_default_fields','insidect_comment_fields');

/**
 *	Change comment field position
 */
function insidect_move_comment_field_to_bottom( $fields ) {
	$comment_field = $fields['comment'];
	unset( $fields['comment'] );
	$fields['comment'] = $comment_field;
	return $fields;
}
add_filter( 'comment_form_fields', 'insidect_move_comment_field_to_bottom' );

/**
 *  Custom search form widget
 */
add_filter( 'get_search_form', 'insidect_search_form_widget', 100 );
function insidect_search_form_widget( $form ) {
    $form =
    '<form role="search" method="get" id="searchform" class="searchform" action="' . esc_url(home_url( '/' )) . '" >
	    <label class="screen-reader-text" for="s">' . esc_html__( 'Search for:', 'insidect' ) . '</label>
	    <input type="text" class="search-field" placeholder="'.esc_attr__('ENTER A KEYWORD', 'insidect').'" value="' . get_search_query() . '" name="s" id="s" />
	    <button type="submit" id="searchsubmit" class="ion-ios-search-strong"></button>
    </form>';
    return $form;
}

/**
 *  Add Sticky class post
 */
function insidect_sticky_class( $classes ) {
    global $post;
    if ( is_sticky( $post->ID ) ) {
        $classes[] = 'sticky-post';
    }
    return $classes;
}
add_filter( 'post_class', 'insidect_sticky_class' );